#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -- -notk "$@"

set auto_path   "[split $env(TCLPATH) :] $auto_path"
set ARGV         [concat $argv0 $argv]
set ARGC         [llength $ARGV]

if {[flagLoc $ARGV -help]} \
   {
    puts "Summarize Results of modelExp.tcl Fitting."
    puts " -in tabName      \[sorted_nlin.tab\]        Master Peak Table."
    puts " -mod modTemplate \[mod/mod%d.tab\]   Model Result Template."
    exit 1
   }

set tabName sorted_nlin.tab
set modName mod/mod%d.tab

getArgD $ARGV -in tabName
getArgD $ARGV -mod modName

#
#--------------------------------------------------------------------------

if {![file exists $tabName]} \
   {
    puts stderr "Error Finding Input Table $tabName"
    exit 1
   }

set pkTab   [gdbRead table -in $tabName]
set idList  [getTabVals $pkTab INDEX]
set assList [getTabVals $pkTab ASS]

set i 0

foreach id $idList \
   {
    set thisName [format $modName $id]
    set ass [lindex $assList $i]

    if {![file exists $thisName]} \
       {
        puts stderr "Notice: Missing Model Result File $thisName"
        continue
       }

    set modTab [gdbRead table -in $thisName]

    getKeyData $modTab fitInfo

    set cList [string trim $fitInfo(OPTIMAL_VALUE) "{}"]
    set eList [string trim $fitInfo(MONTE_CARLO_ERROR) "{}"]
    set n     [llength $cList]

    if {!$i} \
       {
        puts -nonewline "VARS   INDEX ASS"

        for {set j 1} {$j <= $n} {incr j} {puts -nonewline " C$j"}
        for {set j 1} {$j <= $n} {incr j} {puts -nonewline " E$j"}

        puts ""
        puts -nonewline "FORMAT %4d %s"

        for {set j 1} {$j <= $n} {incr j} {puts -nonewline " %e"}
        for {set j 1} {$j <= $n} {incr j} {puts -nonewline " %e"}

        puts ""
        puts ""
       }

    puts -nonewline [format " %4d" $id]
    puts -nonewline [format " %s"  $ass]

    foreach c $cList {puts -nonewline [format " % .4e" $c]}
    foreach e $eList {puts -nonewline [format " % .4e" $e]}

    puts ""

    gdbFree $modTab
    unset fitInfo

    incr i
   }

exit 0

