#!/bin/sh
#
# TCL script to make correction for R1p to extract R2
# Jinfa Ying, 11/2/06, NIDDK/NIH
#
# The next line restarts using nmrWish \
exec nmrWish "$0" -notk -- "$@"
                                                                                                                                                             
set auto_path   "[split $env(TCLPATH) :] $auto_path"
set ARGV        [concat $argv0 $argv]
set ARGC        [llength $ARGV]

set dataDir .

set nmrField 1199.956
getArgD $ARGV -f nmrField

set slField    2000
getArgD $ARGV -sl   slField

set fNameR1p t1rho.tab

set fNameR1  t1.tab

set inTabR1p [gdbRead table -in $dataDir/$fNameR1p]

#read the info in lines starting with REMARK
set text [gdbGetInfo $inTabR1p -parms text]
while {$text} {
   set rmkStr [gdbGetInfo $text -parms value]
   if {[regexp {yOBS} $rmkStr]} {set yObs [lindex $rmkStr 3]}
   if {[regexp {yCAR} $rmkStr]} {set yCar [lindex $rmkStr 3]}
   set text [gdbNext $text]
}

#read experimental R1p from the table
set eList    [gdbGetInfo $inTabR1p -parms entries]
set resList  ""
foreach entry $eList {
   set resID [gdbGet $entry ASS]
   if {[lsearch -exact $resList $resID] < 0} {
      lappend resList $resID
   }
   set obsT1p         [gdbGet $entry C2]
   set obsR1p($resID) [expr 1000.0/$obsT1p]
   set errT1p         [gdbGet $entry E2]
   set errR1p($resID) [expr 1000.0*double($errT1p)/pow($obsT1p, 2)]
#   set cShift($resID) [gdbGet $entry Y_PPM]
}

#read R1
set inTabR1  [gdbRead table -in $dataDir/$fNameR1]
set eList    [gdbGetInfo $inTabR1 -parms entries]
foreach entry $eList {
   set resID         [gdbGet $entry ASS]
   if {[lsearch -exact $resList $resID] < 0} {
      lappend resList $resID
   }
   set T1            [gdbGet $entry C2]
   set R1($resID)    [expr 1000.0/$T1]
   set errT1         [gdbGet $entry E2]
   set errR1($resID) [expr 1000.0*double($errT1)/pow($T1, 2)]
}

set csFile [open "fusionOffset.tab" "r"]
while {[gets $csFile line] >=0} {
   set resID          [lindex $line 0]
   if {[lsearch -exact $resList $resID] < 0} {
      lappend resList $resID
   }
   set cShift($resID) [lindex $line 2]
}

#puts "REMARK hPin1 amide 15N raw R1p, B1(eff) angle, corrected R2 from raw R1p, R1"
#puts "REMARK R2_CRTD obtained from T1p with Off-resonance effect corrected"
#puts "REMARK Measured at $nmrField MHz"
#puts ""
puts "RESID\tR1p_OBS\tR1p_ERR\tTHETA\tR2_CRTD\tR2_ERR\tR1Nz\tR1Nz_ERR"
#puts "FORMAT %8s %8.3f %6.1f %6.1f %8.3f %5.1f %6.3f %6.3f"


#calculate R2 from R1p and R1
foreach res $resList {
   if {[info exist cShift($res)]} {
      if {[info exist obsR1p($res)]} {
         if {[info exist R1($res)]} {
            set offset       [expr abs($yCar-$cShift($res))*$yObs]
            set eField       [expr sqrt(pow($offset,2)+pow($slField,2))]
            set theta        [expr atan($slField/$offset)]
            set angle($res)  [expr $theta*180/3.1415926]
            set sTheta2      [expr pow(sin($theta),2)]
            set cTheta2      [expr pow(cos($theta),2)]
            set R2($res)     [expr ($obsR1p($res)-$R1($res)*$cTheta2)/$sTheta2]
            set errR2($res)  [expr sqrt(pow($errR1p($res),2)+pow($errR1($res)*$cTheta2,2))/$sTheta2]
            puts             "$res\t$obsR1p($res)\t$errR1p($res)\t$angle($res)\t$R2($res)\t$errR2($res)\t$R1($res)\t$errR1($res)"        
	    }
      }
   }
}

exit 0

